@@ -41,7 +41,9 @@ char* pds_sprintf(const char *format, ...)
 {
     char *char_string=NULL;
     char *p=NULL;
-    int N=-1;
+    int N=-1,n;
+    int len,i;
+    char buffer[32];
     int val;
     va_list args;               /* points to each unnamed arg in turn */
 
@@ -52,9 +54,22 @@ char* pds_sprintf(const char *format, ...)
         if (*p == '%') 
         {
             p++;
-            if(*p=='s')         {N = N+strlen(va_arg(args, char *));}
-            else if(*p=='c')    {val = va_arg(args, int); N=N+1;}
-            else                {val = va_arg(args, int); N=N+21;}
+
+            i=0;
+            while(isalpha((int)(*p))==0)
+            {
+                buffer[i]=(char)(*p); 
+                i++;
+                p++;
+            }
+            buffer[i]=0;
+            len=atoi(buffer);
+
+            if(*p=='s')         {n=strlen(va_arg(args, char *));}
+            else if(*p=='c')    {val = va_arg(args, int); n=1;}
+            else                {val = va_arg(args, int); n=64;}//<----Problemas aqui si es entregado %64s
+            if(len>n)   N=N+len;
+            else        N=N+n;
         }
     }
     va_end( args );             /* clean up when done */
@@ -81,18 +96,66 @@ char* pds_sprintf(const char *format, ...)
     return char_string;
 }
 
+/* strsep.c
+   Copyright (C) 1992-2015 Free Software Foundation, Inc.
+   This file is part of the GNU C Library.
+ */
+char *pds_strsep (char **stringp, const char *delim)
+{
+  char *begin, *end;
 
-/** \fn PdsCellString *pds_strsep(const char *str, const char *delim)
+  begin = *stringp;
+  if (begin == NULL)
+    return NULL;
+
+  /* A frequent case is when the delimiter string contains only one
+     character.  Here we don't need to call the expensive `strpbrk'
+     function and instead work using `strchr'.  */
+  if (delim[0] == '\0' || delim[1] == '\0')
+    {
+      char ch = delim[0];
+
+      if (ch == '\0')
+	end = NULL;
+      else
+	{
+	  if (*begin == ch)
+	    end = begin;
+	  else if (*begin == '\0')
+	    end = NULL;
+	  else
+	    end = strchr (begin + 1, ch);
+	}
+    }
+  else
+    /* Find the end of the token.  */
+    end = strpbrk (begin, delim);
+
+  if (end)
+    {
+      /* Terminate the token and set *STRINGP past NUL character.  */
+      *end++ = '\0';
+      *stringp = end;
+    }
+  else
+    /* No more delimiters; this is the last token.  */
+    *stringp = NULL;
+
+  return begin;
+}
+
+/** \fn PdsCellString *pds_strsep_cell_string(const char *str, const char *delim)
  *  \brief Esta función es similar a la función strsep, donde la cadena str es 
  *  dividida usando algunos de los delimitadores especificados en delim. Los 
  *  pedazos son cargados en una estructura PdsCellString* retornada por la función.
  *  \param[in] str Cadena a dividir, esta cadena no sera modificada.
- *  \param[in] delim Delimitadores a usar.
+ *  \param[in] delim Delimitadores a usar. Si delim es NULL la función retorna NULL.
+ *  Si delim es una cadena vacia es retornada la cadena entera dentro de una PdsCellString.
  *  \return Retorna un puntero a una nueva estructura de tipo PdsCellString *,
  *  con los tokens de la división.
  *  \ingroup PdsStringGroup
  */
-PdsCellString *pds_strsep(const char *str, const char *delim)
+PdsCellString *pds_strsep_cell_string(const char *str, const char *delim)
 {
     char *str0 =NULL; 
     char *token=NULL;
@@ -114,7 +177,7 @@ PdsCellString *pds_strsep(const char *str, const char *delim)
 
     str1=str0;
     do{
-        token = strsep(&str0, delim);
+        token = pds_strsep(&str0, delim);
         if(token!=NULL)
         {
             //if(strlen(token)>0) 
